@@ -31,7 +31,7 @@ import datetime
 import time
 import collections
 
-VERSION = (0, 3, 0)
+VERSION = (0, 3, 1)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -490,7 +490,7 @@ class Connection(object):
             data = self._read(ln)
             if code == PG_B_READY_FOR_QUERY:
                 DEBUG_OUTPUT("READY_FOR_QUERY:", data)
-                self.in_transaction = (data in (b'I', b'T'))
+                self.in_transaction = (data == b'T')
                 break
             elif code == PG_B_AUTHENTICATION:
                 auth_method = _bytes_to_bint(data[:4])
@@ -688,14 +688,12 @@ class Connection(object):
         if self.sock:
             self._send_message(PG_F_QUERY, b"COMMIT\x00")
             self._process_messages(None)
-            self.begin()
 
     def rollback(self):
         DEBUG_OUTPUT('ROLLBACK')
         if self.sock:
             self._send_message(PG_F_QUERY, b"ROLLBACK\x00")
             self._process_messages(None)
-            self.begin()
 
     def reopen(self):
         self.close()
